@@ -2,8 +2,8 @@ library(harvestr)
 library(testthat)
 library(plyr)
 
-test_that("testing",{
-message("Ignore printedwarnings they are expected, and impossible to supress.")
+test_that("testing", {
+# message("Ignore printed warnings they are expected, and impossible to supress.")
 { context("gather")
   suppressWarnings(suppressMessages({
     seeds  <- gather(10, seed=1234)
@@ -20,22 +20,41 @@ message("Ignore printedwarnings they are expected, and impossible to supress.")
   expect_false(identical(a, c))  # FALSE
 }
 { context("farm")
+  seeds <- gather(10)
   e <- farm(seeds, rnorm(10))
   f <- farm(seeds, rnorm(10))
-  expect_identical(e,f)
+  expect_equivalent(e,f)
+  
+  seeds <- gather(10)
+  o <- sample(seq_along(seeds))
+  g <- farm(seeds[o], rnorm(10))[order(o)]
+  expect_equivalent(e,g)
 }
 { context("reap")
-  expect_identical(reap(a, sample), reap(a, sample))
+  expect_equivalent(reap(a, sample), reap(a, sample))
+  local({
+    seed <- gather(1)[[1]]
+    x <- plant(list(1:10), list(seed))[[1]]
+    a <- reap(x, sample)
+    b <- withpseed(seed, sample(1:10))
+    expect_identical(a,b)
+  })
 }
 { context("harvest")
   x <- harvest(e, sample, replace=T)
   y <- harvest(e, sample, replace=T)
-  expect_identical(x,y)
+  expect_equivalent(x,y)
+}
+{ context("Permutation")
+  x <- harvest(e, sample, replace=T)
+  o <- sample(seq_along(e))
+  y <- harvest(e[o], sample, replace=T)[order(o)]
+  expect_equivalent(x,y)
 }
 { context("using with")
-  data <- farm(gather(3, seed=1234), data.frame(x123=runif(100), y456=rnorm(100)))
+  data <- farm(gather(3), data.frame(x123=runif(100), y456=rnorm(100)))
   m1 <- harvest(data, with, mean(x123))
   m2 <- lapply(data, with, mean(x123))
-  expect_equivalent(noattr(m1), noattr(m2))
+  expect_equivalent(m1, m2)
 }
 })
